==> checkstyle_8.29.orig.tar.xz: checkstyle-checkstyle-8.29/src/test/resources/com/puppycrawl/tools/checkstyle/checks/indentation/indentation/InputIndentationCustomAnnotation.java <==
package com.puppycrawl.tools.checkstyle.checks.indentation.indentation; //indent:0 exp:0

import java.lang.annotation.ElementType; //indent:0 exp:0
import java.lang.annotation.Repeatable; //indent:0 exp:0
import java.lang.annotation.Retention; //indent:0 exp:0
import java.lang.annotation.RetentionPolicy; //indent:0 exp:0
import java.lang.annotation.Target; //indent:0 exp:0

public @interface InputIndentationCustomAnnotation { //indent:0 exp:0
    int value = 1; //indent:4 exp:4
    int value() default 0; //indent:4 exp:4
} //indent:0 exp:0

     @Retention(RetentionPolicy.SOURCE) @interface AnnotationWithComments { //inside comments //indent:5 exp:0 warn
     } //indent:5 exp:0 warn
     @interface AnnotationWithStringProperty { //indent:5 exp:0 warn
String author(); //indent:0 exp:4 warn
     } //indent:5 exp:0 warn

   @Retention(RetentionPolicy.SOURCE) //indent:3 exp:0 warn
@interface AnnotationWithDefaultStringAndAnnotation { //indent:0 exp:0
String author() default "author"; //indent:0 exp:4 warn
     } //indent:5 exp:0 warn

     @interface //indent:5 exp:0 warn
     AnnotationWithLineWrap { //indent:5 exp:0 warn
    String author(); //indent:4 exp:4
} //indent:0 exp:0

     @Target(ElementType.METHOD) //indent:5 exp:0 warn
   @Retention(RetentionPolicy.RUNTIME) //indent:3 exp:0 warn
@interface AnnotationWithTarget { //indent:0 exp:0
    String author() default "author"; //indent:4 exp:4
     String book(); //indent:5 exp:4 warn
   @Retention(RetentionPolicy.SOURCE) //indent:3 exp:4 warn
@Repeatable(RepeatableInner.class) //indent:0 exp:4 warn
@interface //indent:0 exp:4 warn
        AnnotationInnerLineWrap //indent:8 exp:4 warn
    { //indent:4 exp:4
        public String author() default "auth"; //indent:8 exp:8
       @AnnotationWithTarget(book = "") public String title() default "title"; //indent:7 exp:8 warn
    }//indent:4 exp:4
} //indent:0 exp:0
@interface RepeatableInner { //indent:0 exp:0
    AnnotationWithTarget.AnnotationInnerLineWrap[] value(); //indent:4 exp:4
} //indent:0 exp:0

@interface Ann {} //indent:0 exp:0

class InnerAnonClass { //indent:0 exp:0
    @interface MyInnerAnno { //indent:4 exp:4
        String author(); //indent:8 exp:8
    } //indent:4 exp:4
} //indent:0 exp:0
@Retention(RetentionPolicy.SOURCE) //indent:0 exp:0
@Repeatable(RepeatableInner2.class) //indent:0 exp:0
@interface //indent:0 exp:0
    AnnotationInnerLineWrap2 { //indent:4 exp:0 warn
   public String author() default "auth"; //indent:3 exp:4 warn
       @AnnotationWithTarget(book = "") public String title() default "title"; //indent:7 exp:4 warn
    }//indent:4 exp:0 warn

@interface RepeatableInner2 { //indent:0 exp:0
    AnnotationInnerLineWrap2[] value(); //indent:4 exp:4
} //indent:0 exp:0

@interface RepeatableInner3 { //indent:0 exp:0
    AnnotationInnerLineWrap2[] value(); //indent:4 exp:4
} //indent:0 exp:0

class InnerAnnotSingleLine { //indent:0 exp:0
   @Retention(RetentionPolicy.SOURCE) @interface AnnotationOneLine {} //indent:3 exp:4 warn
} //indent:0 exp:0

@interface AnnotationDef { //indent:0 exp:0
    int value = 1; //indent:4 exp:4
} //indent:0 exp:0

@interface AnnotationDef2 { //indent:0 exp:0
    int value //indent:4 exp:4
        = Integer.parseInt("1"); //indent:8 exp:8
    Object object = new Object(){ //indent:4 exp:4
        @Override //indent:8 exp:8
        public String toString() { //indent:8 exp:8
            return //indent:12 exp:12
                    new String( //indent:20 exp:20
                            new StringBuilder("Hello") //indent:28 exp:28
                                    .append(",World")) //indent:36 exp:36
                    ; //indent:20 exp:20
        } //indent:8 exp:8
    }.toString(); //indent:4 exp:4
} //indent:0 exp:0

@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface Multitude { String value(); } //indent:0 exp:0

@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface MetaConfig { //indent:0 exp:0

	static class DevConfig { //indent:4 exp:4
	} //indent:4 exp:4

	static class ProductionConfig { //indent:4 exp:4
	} //indent:4 exp:4
	Class<?>[] classes() default { DevConfig.class, ProductionConfig.class }; //indent:4 exp:4
} //indent:0 exp:0

@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface Multitudes { Multitude[] value(); } //indent:0 exp:0

@java.lang.annotation.Retention(java.lang.annotation.RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface Aclass { //indent:0 exp:0
    String b(); //indent:4 exp:4
    String[] c(); //indent:4 exp:4
} //indent:0 exp:0
class InnerAnnotSingleLine2 { //indent:0 exp:0
     @Retention(RetentionPolicy.SOURCE) @interface AnnotationOneLine {} //indent:5 exp:4 warn
} //indent:0 exp:0
@interface RepeatableInner4 { //indent:0 exp:0
    public AnnotationWithTarget.AnnotationInnerLineWrap[] value(); //indent:4 exp:4
} //indent:0 exp:0
@interface HelloAnnot { //indent:0 exp:0
    public //indent:4 exp:4
        String myString() //indent:8 exp:8
        default "Hello"; //indent:8 exp:8
} //indent:0 exp:0
@ //indent:0 exp:0
 interface //indent:1 exp:0 warn
MyAnnotationWrapped { //indent:0 exp:0
    int value() default -1; //indent:4 exp:4
    AnnotationWithTarget.AnnotationInnerLineWrap field(); //indent:4 exp:4
} //indent:0 exp:0
@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
           @interface Marker {} //indent:11 exp:0 warn
@Target({ ElementType.METHOD, ElementType.TYPE_PARAMETER }) //indent:0 exp:0
@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
				@interface FetchProfile { //indent:16 exp:0 warn
	String name(); //indent:4 exp:4

	FetchOverride[] fetchOverrides(); //indent:4 exp:4

	@Target({ ElementType.TYPE, ElementType.METHOD }) //indent:4 exp:4
	@Retention(RetentionPolicy.RUNTIME) //indent:4 exp:4
			@interface FetchOverride { //indent:12 exp:4 warn
		String association(); //indent:8 exp:8
	} //indent:4 exp:4
} //indent:0 exp:0
				class FetchProfile2 { //indent:16 exp:0 warn
	String name; //indent:4 exp:4

	FetchOverride2[] fetchOverrides; //indent:4 exp:4

	@Target({ ElementType.TYPE, ElementType.METHOD }) //indent:4 exp:4
    @interface FetchOverride2 { //indent:4 exp:4
		String association(); //indent:8 exp:8
	} //indent:4 exp:4
} //indent:0 exp:0

==> checkstyle_8.36.1.orig.tar.xz: checkstyle-checkstyle-8.36.1/src/test/resources/com/puppycrawl/tools/checkstyle/checks/indentation/indentation/InputIndentationCustomAnnotation.java <==
package com.puppycrawl.tools.checkstyle.checks.indentation.indentation; //indent:0 exp:0

import java.lang.annotation.ElementType; //indent:0 exp:0
import java.lang.annotation.Repeatable; //indent:0 exp:0
import java.lang.annotation.Retention; //indent:0 exp:0
import java.lang.annotation.RetentionPolicy; //indent:0 exp:0
import java.lang.annotation.Target; //indent:0 exp:0

public @interface InputIndentationCustomAnnotation { //indent:0 exp:0
    int value = 1; //indent:4 exp:4
    int value() default 0; //indent:4 exp:4
} //indent:0 exp:0

     @Retention(RetentionPolicy.SOURCE) @interface AnnotationWithComments { // //indent:5 exp:0 warn
     } //indent:5 exp:0 warn
     @interface AnnotationWithStringProperty { //indent:5 exp:0 warn
String author(); //indent:0 exp:4 warn
     } //indent:5 exp:0 warn

   @Retention(RetentionPolicy.SOURCE) //indent:3 exp:0 warn
@interface AnnotationWithDefaultStringAndAnnotation { //indent:0 exp:0
String author() default "author"; //indent:0 exp:4 warn
     } //indent:5 exp:0 warn

     @interface //indent:5 exp:0 warn
     AnnotationWithLineWrap { //indent:5 exp:0 warn
    String author(); //indent:4 exp:4
} //indent:0 exp:0

     @Target(ElementType.METHOD) //indent:5 exp:0 warn
   @Retention(RetentionPolicy.RUNTIME) //indent:3 exp:0 warn
@interface AnnotationWithTarget { //indent:0 exp:0
    String author() default "author"; //indent:4 exp:4
     String book(); //indent:5 exp:4 warn
   @Retention(RetentionPolicy.SOURCE) //indent:3 exp:4 warn
@Repeatable(RepeatableInner.class) //indent:0 exp:4 warn
@interface //indent:0 exp:4 warn
        AnnotationInnerLineWrap //indent:8 exp:4 warn
    { //indent:4 exp:4
        public String author() default "auth"; //indent:8 exp:8
       @AnnotationWithTarget(book = "") public String title() default "title"; //indent:7 exp:8 warn
    }//indent:4 exp:4
} //indent:0 exp:0
@interface RepeatableInner { //indent:0 exp:0
    AnnotationWithTarget.AnnotationInnerLineWrap[] value(); //indent:4 exp:4
} //indent:0 exp:0

@interface Ann {} //indent:0 exp:0

class InnerAnonClass { //indent:0 exp:0
    @interface MyInnerAnno { //indent:4 exp:4
        String author(); //indent:8 exp:8
    } //indent:4 exp:4
} //indent:0 exp:0
@Retention(RetentionPolicy.SOURCE) //indent:0 exp:0
@Repeatable(RepeatableInner2.class) //indent:0 exp:0
@interface //indent:0 exp:0
    AnnotationInnerLineWrap2 { //indent:4 exp:0 warn
   public String author() default "auth"; //indent:3 exp:4 warn
       @AnnotationWithTarget(book = "") public String title() default "title"; //indent:7 exp:4 warn
    }//indent:4 exp:0 warn

@interface RepeatableInner2 { //indent:0 exp:0
    AnnotationInnerLineWrap2[] value(); //indent:4 exp:4
} //indent:0 exp:0

@interface RepeatableInner3 { //indent:0 exp:0
    AnnotationInnerLineWrap2[] value(); //indent:4 exp:4
} //indent:0 exp:0

class InnerAnnotSingleLine { //indent:0 exp:0
   @Retention(RetentionPolicy.SOURCE) @interface AnnotationOneLine {} //indent:3 exp:4 warn
} //indent:0 exp:0

@interface AnnotationDef { //indent:0 exp:0
    int value = 1; //indent:4 exp:4
} //indent:0 exp:0

@interface AnnotationDef2 { //indent:0 exp:0
    int value //indent:4 exp:4
        = Integer.parseInt("1"); //indent:8 exp:8
    Object object = new Object(){ //indent:4 exp:4
        @Override //indent:8 exp:8
        public String toString() { //indent:8 exp:8
            return //indent:12 exp:12
                    new String( //indent:20 exp:20
                            new StringBuilder("Hello") //indent:28 exp:28
                                    .append(",World")) //indent:36 exp:36
                    ; //indent:20 exp:20
        } //indent:8 exp:8
    }.toString(); //indent:4 exp:4
} //indent:0 exp:0

@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface Multitude { String value(); } //indent:0 exp:0

@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface MetaConfig { //indent:0 exp:0

	static class DevConfig { //indent:4 exp:4
	} //indent:4 exp:4

	static class ProductionConfig { //indent:4 exp:4
	} //indent:4 exp:4
	Class<?>[] classes() default { DevConfig.class, ProductionConfig.class }; //indent:4 exp:4
} //indent:0 exp:0

@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface Multitudes { Multitude[] value(); } //indent:0 exp:0

@java.lang.annotation.Retention(java.lang.annotation.RetentionPolicy.RUNTIME) //indent:0 exp:0
@interface Aclass { //indent:0 exp:0
    String b(); //indent:4 exp:4
    String[] c(); //indent:4 exp:4
} //indent:0 exp:0
class InnerAnnotSingleLine2 { //indent:0 exp:0
     @Retention(RetentionPolicy.SOURCE) @interface AnnotationOneLine {} //indent:5 exp:4 warn
} //indent:0 exp:0
@interface RepeatableInner4 { //indent:0 exp:0
    public AnnotationWithTarget.AnnotationInnerLineWrap[] value(); //indent:4 exp:4
} //indent:0 exp:0
@interface HelloAnnot { //indent:0 exp:0
    public //indent:4 exp:4
        String myString() //indent:8 exp:8
        default "Hello"; //indent:8 exp:8
} //indent:0 exp:0
@ //indent:0 exp:0
 interface //indent:1 exp:0 warn
MyAnnotationWrapped { //indent:0 exp:0
    int value() default -1; //indent:4 exp:4
    AnnotationWithTarget.AnnotationInnerLineWrap field(); //indent:4 exp:4
} //indent:0 exp:0
@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
           @interface Marker {} //indent:11 exp:0 warn
@Target({ ElementType.METHOD, ElementType.TYPE_PARAMETER }) //indent:0 exp:0
@Retention(RetentionPolicy.RUNTIME) //indent:0 exp:0
				@interface FetchProfile { //indent:16 exp:0 warn
	String name(); //indent:4 exp:4

	FetchOverride[] fetchOverrides(); //indent:4 exp:4

	@Target({ ElementType.TYPE, ElementType.METHOD }) //indent:4 exp:4
	@Retention(RetentionPolicy.RUNTIME) //indent:4 exp:4
			@interface FetchOverride { //indent:12 exp:4 warn
		String association(); //indent:8 exp:8
	} //indent:4 exp:4
} //indent:0 exp:0
				class FetchProfile2 { //indent:16 exp:0 warn
	String name; //indent:4 exp:4

	FetchOverride2[] fetchOverrides; //indent:4 exp:4

	@Target({ ElementType.TYPE, ElementType.METHOD }) //indent:4 exp:4
    @interface FetchOverride2 { //indent:4 exp:4
		String association(); //indent:8 exp:8
	} //indent:4 exp:4
} //indent:0 exp:0
